# my_datetime_project.py
import datetime

def print_current_time():
    """Print the current date and time"""
    now = datetime.datetime.now()
    print("Current Date and Time: ", now)


if __name__ == "__main__":
    print_current_time()
